@@ -58,7 +58,7 @@ G_DEFINE_TYPE_WITH_CODE (GoaGoogleProvider, goa_google_provider, GOA_TYPE_OAUTH2
                          goa_provider_ensure_extension_points_registered ();
                          g_io_extension_point_implement (GOA_PROVIDER_EXTENSION_POINT_NAME,
 							 g_define_type_id,
-							 "google",
+							 GOA_GOOGLE_NAME,
 							 0));
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -66,7 +66,7 @@ G_DEFINE_TYPE_WITH_CODE (GoaGoogleProvider, goa_google_provider, GOA_TYPE_OAUTH2
 static const gchar *
 get_provider_type (GoaProvider *_provider)
 {
-  return "google";
+  return GOA_GOOGLE_NAME;
 }
 
 static gchar *
@@ -146,13 +146,16 @@ get_scope (GoaOAuth2Provider *provider)
          "https://www.googleapis.com/auth/cloudprint "
 
          /* Google Talk */
-         "https://www.googleapis.com/auth/googletalk";
+         "https://www.googleapis.com/auth/googletalk "
+
+         /* Google Tasks - undocumented */
+         "https://www.googleapis.com/auth/tasks";
 }
 
 static guint
 get_credentials_generation (GoaProvider *provider)
 {
-  return 8;
+  return 9;
 }
 
 static const gchar *
@@ -255,11 +258,9 @@ get_identity_sync (GoaOAuth2Provider  *provider,
 
  out:
   g_clear_error (&identity_error);
+  g_clear_object (&call);
+  g_clear_object (&proxy);
   g_free (email);
-  if (call != NULL)
-    g_object_unref (call);
-  if (proxy != NULL)
-    g_object_unref (proxy);
   return ret;
 }
 
