@@ -61,7 +61,7 @@ G_DEFINE_TYPE_WITH_CODE (GoaOwncloudProvider, goa_owncloud_provider, GOA_TYPE_PR
                          goa_provider_ensure_extension_points_registered ();
                          g_io_extension_point_implement (GOA_PROVIDER_EXTENSION_POINT_NAME,
 							 g_define_type_id,
-							 "owncloud",
+							 GOA_OWNCLOUD_NAME,
 							 0));
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -73,7 +73,7 @@ static const gchar *WEBDAV_ENDPOINT = "remote.php/webdav/";
 static const gchar *
 get_provider_type (GoaProvider *provider)
 {
-  return "owncloud";
+  return GOA_OWNCLOUD_NAME;
 }
 
 static gchar *
