@@ -66,7 +66,7 @@ G_DEFINE_TYPE_WITH_CODE (GoaPocketProvider, goa_pocket_provider, GOA_TYPE_OAUTH2
                          goa_provider_ensure_extension_points_registered ();
                          g_io_extension_point_implement (GOA_PROVIDER_EXTENSION_POINT_NAME,
                                                          g_define_type_id,
-                                                         "pocket",
+                                                         GOA_POCKET_NAME,
                                                          0));
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -74,7 +74,7 @@ G_DEFINE_TYPE_WITH_CODE (GoaPocketProvider, goa_pocket_provider, GOA_TYPE_OAUTH2
 static const gchar *
 get_provider_type (GoaProvider *_provider)
 {
-  return "pocket";
+  return GOA_POCKET_NAME;
 }
 
 static gchar *
@@ -394,10 +394,8 @@ build_object (GoaProvider         *provider,
   ret = TRUE;
 
  out:
-  if (readlater != NULL)
-    g_object_unref (readlater);
-  if (account != NULL)
-    g_object_unref (account);
+  g_clear_object (&readlater);
+  g_clear_object (&account);
   return ret;
 }
 
