@@ -60,7 +60,7 @@ G_DEFINE_TYPE_WITH_CODE (GoaWindowsLiveProvider, goa_windows_live_provider, GOA_
                          goa_provider_ensure_extension_points_registered ();
                          g_io_extension_point_implement (GOA_PROVIDER_EXTENSION_POINT_NAME,
 							 g_define_type_id,
-							 "windows_live",
+							 GOA_WINDOWS_LIVE_NAME,
 							 0));
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -68,7 +68,7 @@ G_DEFINE_TYPE_WITH_CODE (GoaWindowsLiveProvider, goa_windows_live_provider, GOA_
 static const gchar *
 get_provider_type (GoaProvider *_provider)
 {
-  return "windows_live";
+  return GOA_WINDOWS_LIVE_NAME;
 }
 
 static gchar *
@@ -243,12 +243,10 @@ get_identity_sync (GoaOAuth2Provider  *provider,
 
  out:
   g_clear_error (&identity_error);
+  g_clear_object (&call);
+  g_clear_object (&proxy);
   g_free (id);
   g_free (presentation_identity);
-  if (call != NULL)
-    g_object_unref (call);
-  if (proxy != NULL)
-    g_object_unref (proxy);
   return ret;
 }
 
@@ -397,8 +395,7 @@ build_object (GoaProvider         *provider,
  out:
   g_clear_object (&documents);
   g_clear_object (&mail);
-  if (account != NULL)
-    g_object_unref (account);
+  g_clear_object (&account);
   return ret;
 }
 
